@@ -43,6 +43,14 @@ class APIClient:
         response.raise_for_status()
         return response.json()
 
+    @api_exception_wrapper
+    def fetch_database(self, database_id):
+        url = f'{BACKEND_URL}/operations/database-instances/{database_id}/'
+        headers = {'Authorization': f'Token {self.token}'}
+        response = requests.get(url, headers=headers)
+        response.raise_for_status()
+        return response.json()
+
     @api_exception_wrapper
     def fetch_image(self, image_id):
         url = f'{BACKEND_URL}/operations/images/{image_id}/'
@@ -166,13 +174,15 @@ class APIClient:
         return response.json()
 
     @api_exception_wrapper
-    def create_volume(self, project_id, name):
+    def create_volume(self, project_id, name, capacity=None):
         url = f'{BACKEND_URL}/operations/volumes/'
         headers = {'Authorization': f'Token {self.token}'}
         data = {
             'project_id': project_id,
             'name': name
         }
+        if capacity:
+            data['capacity'] = capacity
         response = requests.post(url, headers=headers, json=data)
         response.raise_for_status()
         return response.json()
@@ -192,6 +202,20 @@ class APIClient:
         response.raise_for_status()
         return response.json()
 
+    @api_exception_wrapper
+    def create_domain(self, service_id, base, https_active=True, https_redirect_code=None):
+        url = f'{BACKEND_URL}/operations/domains/'
+        headers = {'Authorization': f'Token {self.token}'}
+        data = {
+            'service_id': service_id,
+            'base': base,
+            'https_active': https_active,
+            'https_redirect': https_redirect_code
+        }
+        response = requests.post(url, headers=headers, json=data)
+        response.raise_for_status()
+        return response.json()
+
     @api_exception_wrapper
     def commit_image(self, image_id):
         url = f'{BACKEND_URL}/operations/images/{image_id}/commit/'
@@ -200,6 +224,14 @@ class APIClient:
         response.raise_for_status()
         return response.json()
 
+    @api_exception_wrapper
+    def commit_database(self, database_id):
+        url = f'{BACKEND_URL}/operations/database-instances/{database_id}/commit/'
+        headers = {'Authorization': f'Token {self.token}'}
+        response = requests.post(url, headers=headers)
+        response.raise_for_status()
+        return response.json()
+
     @api_exception_wrapper
     def list_services(self, project_id, type_id=None, search=None, limit=20, offset=0):
         url = f'{BACKEND_URL}/operations/services/'
