@@ -41,23 +41,54 @@ mass_update_parser.add_argument('--tag', help='Tag to update')
 mass_update_parser.add_argument('--branch', help='Branch to update. use tag if no branch is selected', required=False)
 
 create_parser = subparsers.add_parser('create', help='Create a service')
+create_subparsers = create_parser.add_subparsers(dest='create_type', help='sub-command help')
 
-create_parser.add_argument('project_id', help='Project ID to create service in', type=int)
-create_parser.add_argument('service_name', help='Name of service to create')
-create_parser.add_argument('--base_service_id', help='Base service ID to use for service creation', type=int)
-create_parser.add_argument('--test-domain', help='Test domain to use for service creation', required=False)
-create_parser.add_argument('--no-new-image', help='Do not create a new image', action='store_true', default=False)
-create_parser.add_argument('--no-deploy', help='Do not deploy service', action='store_true', default=False)
-create_parser.add_argument('--share-storage', help='Share storage with base service', action='store_true',
-                           default=False)
+create_service_parser = create_subparsers.add_parser('service', help='Create a service')
 
-create_db = subparsers.add_parser('create-db', help='Create a database')
+create_service_parser.add_argument('project_id', help='Project ID to create service in', type=int)
+create_service_parser.add_argument('service_name', help='Name of service to create')
+create_service_parser.add_argument('--base_service_id', help='Base service ID to use for service creation', type=int)
+create_service_parser.add_argument('--test-domain', help='Test domain to use for service creation', required=False)
+create_service_parser.add_argument('--domains', nargs='+', help='Domains to use for service creation', required=False)
+create_service_parser.add_argument(
+    '--domains-ssl-redirect-code',
+    help='SSL redirect code to use for all domains. leave empty to disable SSL redirect',
+    required=False,
+    type=int,
+    choices=[301, 302, 307]
+)
+create_service_parser.add_argument(
+    '--envs-file',
+    help='File containing environment variables to use for service creation',
+    required=False
+)
+create_service_parser.add_argument(
+    '--no-new-image',
+    help='Do not create a new image',
+    action='store_true',
+    default=False
+)
+create_service_parser.add_argument('--no-deploy', help='Do not deploy service', action='store_true', default=False)
+create_service_parser.add_argument(
+    '--share-storage',
+    help='Share storage with base service',
+    action='store_true',
+    default=False
+)
+create_service_parser.add_argument(
+    '--volumes-capacity',
+    help='Capacity of all volumes in Byte',
+    required=False,
+    type=int
+)
 
-create_db.add_argument('project_id', help='Project ID to create database in', type=int)
-create_db.add_argument('db_name', help='Name of database to create')
-create_db.add_argument('--type-id', help='Type ID of database to create', type=int)
-create_db.add_argument('--image-id', help='Image ID of database to create', type=int)
-create_db.add_argument('--quota-id', help='Quota ID of database to create', type=int)
+create_db_parser = create_subparsers.add_parser('db', help='Create a database')
+
+create_db_parser.add_argument('project_id', help='Project ID to create database in', type=int)
+create_db_parser.add_argument('db_name', help='Name of database to create')
+create_db_parser.add_argument('--type-id', help='Type ID of database to create', type=int)
+create_db_parser.add_argument('--image-id', help='Image ID of database to create', type=int)
+create_db_parser.add_argument('--quota-id', help='Quota ID of database to create', type=int)
 
 token = None
 client = APIClient(token)
@@ -101,6 +132,15 @@ def handle_mass_update(args):
 
 
 def handle_create(args):
+    if args.create_type == 'service':
+        handle_create_service(args)
+    elif args.create_type == 'db':
+        handle_create_db(args)
+    else:
+        raise Exception("Unknown create type")
+
+
+def handle_create_service(args):
     base_service = client.fetch_service(args.base_service_id)
 
     if base_service['project_id'] != args.project_id:
@@ -117,7 +157,12 @@ def handle_create(args):
             branch=base_image['git_branch']
         )['id']
 
-    test_domain = args.test_domain or f"{args.service_name}-{hex(uuid.uuid4().int)[:6]}"
+    test_domain = args.test_domain or f"{args.service_name}-{str(uuid.uuid4().int)[:6]}"
+
+    envs = {}
+    if args.envs_file:
+        with open(args.envs_file, 'r') as f:
+            envs = json.load(f)
 
     service = client.create_service(
         args.project_id,
@@ -125,7 +170,7 @@ def handle_create(args):
         type_id=base_service['type']['id'],
         image_id=image_id,
         quota_id=base_service['quota']['id'],
-        env_vars=base_service['envs'],
+        env_vars={**base_service['envs'], **envs},
         test_domain=test_domain
     )
     print(f"{service['name']} service has been created with ID {service['id']}")
@@ -139,9 +184,11 @@ def handle_create(args):
             print(f"Creating {len(volume_relations)} volumes")
             sleep(1)
             for volume_relation in volume_relations:
+                capacity = args.volumes_capacity or volume_relation['volume'].get('capacity')
                 volume_relation['volume'] = client.create_volume(
                     project_id=args.project_id,
-                    name=f"{args.service_name}-vol-{hex(uuid.uuid4().int)[:6]}",
+                    name=f"{args.service_name}-vol-{str(uuid.uuid4().int)[:6]}",
+                    capacity=capacity,
                 )
             print("Volumes created")
 
@@ -156,6 +203,14 @@ def handle_create(args):
             )
             print(f"Volume {volume_relation['volume']['name']} attached")
 
+    if args.domains:
+        for domain in args.domains:
+            client.create_domain(
+                service_id=service['id'],
+                base=domain,
+                https_redirect_code=args.domains_ssl_redirect_code,
+            )
+
     if args.no_deploy is False:
         if image_id == base_service['image_id']:
             images = []
@@ -169,11 +224,12 @@ def handle_create(args):
 
 
 def handle_create_db(args):
+    args.db_name = args.db_name.replace('_', '-')
     type_ = client.fetch_database_type(args.type_id)
     volumes = client.list_defaults(
         content_type_name='databaseinstance',
         field_name='volumes',
-        service_type_codename=type_['codename']
+        service_type_codename=type_['code_name']
     )['results'] or []
     db = client.create_database(
         project_id=args.project_id,
@@ -182,28 +238,38 @@ def handle_create_db(args):
         image_id=args.image_id,
         quota_id=args.quota_id
     )
-    print(f"{db['name']} database has been created with ID {db['id']}")
+    print(f"{db['initial_db_name']} database has been created with ID {db['id']}")
     if volumes:
         print(f"Creating {len(volumes)} volumes")
     for volume in volumes:
         volume = json.loads(volume['value'])
-        volume_id = client.create_volume(args.project_id, volume['name'])['id']
-        print(f"Attaching volume {volume['name']} to {db['name']}")
+        volume_obj = client.create_volume(
+            args.project_id,
+            f"{db['initial_db_name']}-{volume['name']}-{str(uuid.uuid4().int)[:6]}"
+        )
+        print(f"Attaching volume {volume_obj['name']} to {db['initial_db_name']}")
         client.create_deployment_volume(
-            volume_id=volume_id,
+            volume_id=volume_obj['id'],
             deployment_id=db['id'],
             deployment_type='database',
             mount_path=volume['target'],
             size=volume.get('capacity', None)
         )
-        print(f"Volume {volume['name']} attached")
+        print(f"Volume {volume_obj['name']} attached")
+
+    client.commit_database(db['id'])
+    print(f"{db['initial_db_name']} database image begins to deploy")
+
+    sleep(1)
+    db = client.fetch_database(db['id'])
+
+    print(f"hostname: {db['host']}")
 
 
 handlers = {
     'update': handle_update,
     'update-mass': handle_mass_update,
     'create': handle_create,
-    'create-db': handle_create_db,
 }
 
 
